"""Top-level package for Contraptions."""

# Package info:
__author__ = """Ryan Fleck"""
__email__ = "Ryan.Fleck@protonmail.com"
__version__ = "3.10.3"

# Export all functions:
from .math import *
from .strings import *
